@@ -1,10 +1,11 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2000-2004 Free Software Foundation
+   Copyright (C) 2000-2010 Free Software Foundation
 
    Authors: Philippe C.D. Robert
             Serg Stoyan
+	    Riccardo Mottola
 
    This file is part of GNUstep.
 
@@ -444,7 +445,7 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
       return nil;
     }
 
-  NSLog(@"Convert legacy");
+  PCLogInfo(self, @"Converting legacy project");
 
   // Gorm project type doesn't exists anymore
   if ([projectClassName isEqualToString:@"PCGormProj"] ||
@@ -517,6 +518,10 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
       [fm movePath:_file toPath:_2file handler:nil];
     }
 
+  /* remove non meaningful keys */
+  [pDict removeObjectForKey: PCWindows];
+  [pDict removeObjectForKey: PCLastEditing];
+
   // GNUmakefiles will be generated in [PCProject initWithProjectDictionary:]
 
   // Remove obsolete records from project dictionary and write to PC.project
@@ -540,55 +545,92 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
   return project;
 }
 
+// aPath is path to a project file PC.project or project bundle *.pcproj.
+// Also it can be project directory where one of the above resides.
 - (PCProject *)openProjectAt:(NSString *)aPath makeActive: (BOOL)flag
 {
+  NSString     *projectPath = nil;
+  NSString     *projectFileType = nil;
   PCProject    *project = nil;
   NSDictionary *wap = nil;
-  
-  if ((project = [loadedProjects objectForKey: [aPath stringByDeletingLastPathComponent]]) == nil)
+
+  // Check project path for invalid characters
+  if ([aPath rangeOfString: @" "].location != NSNotFound ||
+      [aPath rangeOfString: @"\t"].location != NSNotFound ||
+      [aPath rangeOfString: @"\r"].location != NSNotFound ||
+      [aPath rangeOfString: @"\n"].location != NSNotFound)
+    {
+      if (NSRunAlertPanel 
+	  (@"Open Project",
+	   @"Project path contains whitespaces.\n"
+	   @"GNUstep's build environment currently "
+	   @"can't handle that reliably.\n"
+	   @"Do you want to open a project anyway?\n",
+	   @"Open", @"Don't open", nil) != NSAlertDefaultReturn)
+	{
+	  return nil;
+	}
+    }
+
+  projectFileType = [[aPath lastPathComponent] pathExtension];
+  if ([projectFileType isEqualToString:@"pcproj"] || 
+      [projectFileType isEqualToString:@"project"])
+    {
+      projectPath = [aPath stringByDeletingLastPathComponent];
+    }
+  else
+    {
+      projectPath = aPath;
+    }
+
+  if ((project = [loadedProjects objectForKey:projectPath])== nil)
     {  
-      NSMutableDictionary    *projectFile = nil;
-      NSString               *projectTypeName = nil;
-      NSString               *projectClassName = nil;
-      BOOL         isDir = NO;
-      BOOL         exists = [[NSFileManager defaultManager] fileExistsAtPath:aPath 
-							    isDirectory: &isDir];
+      NSMutableDictionary *projectFile = nil;
+      NSString            *projectTypeName = nil;
+      NSString            *projectClassName = nil;
+      BOOL                isDir = NO;
+      BOOL                exists = NO;
+      NSArray             *tempList;
+
+      exists = [[NSFileManager defaultManager] fileExistsAtPath:aPath 
+						    isDirectory:&isDir];
       if (!exists)
 	{
 	  return nil;
 	}
-      
-      if ([aPath rangeOfString: @" "].location != NSNotFound ||
-	  [aPath rangeOfString: @"\t"].location != NSNotFound ||
-	  [aPath rangeOfString: @"\r"].location != NSNotFound ||
-	  [aPath rangeOfString: @"\n"].location != NSNotFound)
+
+      if (isDir)
 	{
-	  if (NSRunAlertPanel 
-	      (@"Open Project",
-	       @"Are you sure you want to open a project with whitespace in it's path?\n"
-	       @"GNUstep's build environment currently can't handle that reliably.",
-	       @"OK", @"Cancel", nil) != NSAlertDefaultReturn)
+	  if ([projectFileType isEqualToString:@"pcproj"] == NO)
 	    {
-	      return nil;
+	      tempList = [fileManager filesWithExtension:@"pcproj"
+						  atPath:aPath
+					     includeDirs:YES];
+	      if ([tempList count] > 0)
+		{
+		  aPath = [tempList objectAtIndex:0];
+		}
+	    }
+	  aPath = [aPath stringByAppendingPathComponent:@"PC.project"];
+	  projectFile = [NSMutableDictionary dictionaryWithContentsOfFile:aPath];
+	}
+      else if ([projectFileType isEqualToString:@"project"])
+	{
+	  projectFile = [NSMutableDictionary dictionaryWithContentsOfFile:aPath];
+	}
+      else
+	{ //TODO: Remove support of 0.3.x projects
+	  projectFile = [NSMutableDictionary dictionaryWithContentsOfFile:aPath];
+	  if (projectFile != nil)
+	    {
+	      // For compatibility with 0.3.x projects
+	      project = [self convertLegacyProject:projectFile atPath:aPath];
 	    }
 	}
 
-      if (!isDir)
-	{
-	  projectFile = [NSMutableDictionary dictionaryWithContentsOfFile: aPath];	  
-	}
-      else
-	{
-	  projectFile = [NSMutableDictionary dictionaryWithContentsOfFile: [aPath stringByAppendingPathComponent: @"PC.project"]];
-	}
-      
-      if(projectFile == nil)
-	{
+      if (projectFile == nil)
 	  return nil;
-	}
-      
-      // For compatibility with 0.3.x projects
-      project = [self convertLegacyProject: projectFile atPath: aPath];
+
       if (project)
 	{// Project was converted and created PC*Project with alloc&init
 	  aPath = [[aPath stringByDeletingLastPathComponent]
@@ -609,8 +651,8 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
 	}
       
       project = [bundleManager objectForClassName:projectClassName
-			       bundleType:@"project"
-			       protocol:@protocol(ProjectType)];
+				       bundleType:@"project"
+			  		 protocol:@protocol(ProjectType)];
       
       if (!project || ![project openWithWrapperAt:aPath]) 
 	{
@@ -632,26 +674,26 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
 	  return nil;
 	}
       
-      [loadedProjects setObject:project forKey: [project projectPath]];
-      [project setProjectManager:self];
-      
-      // Windows and panels
-      wap = [projectFile objectForKey:PCWindows];
-      if ([[wap allKeys] containsObject:@"ProjectBuild"])
-	{
-	  [[project projectWindow] showProjectBuild:self];
-	}
-      if ([[wap allKeys] containsObject:@"ProjectLaunch"])
-	{
-	  [[project projectWindow] showProjectLaunch:self];
-	}
-      if ([[wap allKeys] containsObject:@"LoadedFiles"])
-	{
-	  [[project projectWindow] showProjectLoadedFiles:self];
-	}
-      
+      [loadedProjects setObject:project forKey:[project projectPath]];
       if (flag)
 	{
+	  [project setProjectManager:self];
+	  
+	  // Windows and panels
+	  wap = [projectFile objectForKey:PCWindows];
+	  if ([[wap allKeys] containsObject:@"ProjectBuild"])
+	    {
+	      [[project projectWindow] showProjectBuild:self];
+	    }
+	  if ([[wap allKeys] containsObject:@"ProjectLaunch"])
+	    {
+	      [[project projectWindow] showProjectLaunch:self];
+	    }
+	  if ([[wap allKeys] containsObject:@"LoadedFiles"])
+	    {
+	      [[project projectWindow] showProjectLoadedFiles:self];
+	    }
+	  
 	  [[project projectWindow] makeKeyAndOrderFront:self];
 	  [self setActiveProject: project];
 	}
@@ -662,11 +704,14 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
 
 - (void)openProject
 {
-  NSArray  *files = nil;
-  NSString *filePath = nil, *temp = nil;
-  NSArray  *fileTypes = [NSArray arrayWithObjects:@"pcproj",@"project",nil];
-  NSEnumerator *en = nil;
+  NSArray       *fileTypes = nil;
+  NSArray       *files = nil;
+  NSString      *filePath = nil;
+  NSFileManager *fm = [NSFileManager defaultManager];
+  BOOL          isDir;
+  NSArray       *tempList = nil;
 
+  fileTypes = [NSArray arrayWithObjects:@"pcproj",@"project",nil];
   files = [fileManager filesOfTypes:fileTypes
 			  operation:PCOpenProjectOperation
 			   multiple:NO
@@ -674,18 +719,28 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
 			    accView:nil];
 
   filePath = [files objectAtIndex:0];
-  en = [files objectEnumerator];
-  while((temp = [en nextObject]) != nil)
+
+  [fm fileExistsAtPath:filePath isDirectory:&isDir];
+  if (isDir)
     {
-      if([[temp pathExtension] isEqual: @"pcproj"])
+      if (![[filePath pathExtension] isEqualToString:@"pcproj"])
 	{
-	  filePath = temp;
+	  tempList = [fileManager filesWithExtension:@"pcproj" 
+					      atPath:filePath
+					 includeDirs:YES];
+	  if ([tempList count] > 0)
+	    {
+	      filePath = [tempList objectAtIndex:0];
+	    }
 	}
+      filePath = [filePath stringByAppendingPathComponent:@"PC.project"];
     }
 
+  NSLog(@"PCPM: openProject: %@", filePath);
+
   if (filePath != nil)
     {
-      [self openProjectAt:filePath makeActive: YES];
+      [self openProjectAt:filePath makeActive:YES];
     }
 }
 
@@ -695,7 +750,7 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
   NSString               *className = [projectTypes objectForKey:projectType];
   PCProject<ProjectType> *projectCreator;
   PCProject              *project = nil;
-
+ 
   if ((project = [loadedProjects objectForKey: [aPath stringByDeletingLastPathComponent]]) != nil)
     {
       [[project projectWindow] makeKeyAndOrderFront:self];
@@ -745,13 +800,12 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
 {
   NSArray   *files;
   NSString  *filePath;
-  NSArray   *fileTypes = [NSArray arrayWithObjects:@"project",@"pcproj",nil];
   NSString  *projectType;
   PCProject *project;
 
   [self createProjectTypeAccessaryView];
   
-  files = [fileManager filesOfTypes:fileTypes
+  files = [fileManager filesOfTypes:nil
 			  operation:PCSaveFileOperation
 			   multiple:NO
 			      title:@"New Project"
@@ -1023,13 +1077,12 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
 - (BOOL)closeAllProjects
 {
   PCProject      *project = nil;
-  NSEnumerator   *enumerator = [loadedProjects objectEnumerator];
+  NSEnumerator   *enumerator = [[loadedProjects allValues] objectEnumerator];
 
 //  PCLogInfo(self, @"loaded %i projects", [loadedProjects count]);
 
-  while ([loadedProjects count] > 0)
+  while ((project = [enumerator nextObject]) != nil)
     {
-      project = [enumerator nextObject];
       if ([prefController boolForKey:SaveOnQuit])
 	{
 	  [project save];
