@@ -1,10 +1,11 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2001-2004 Free Software Foundation
+   Copyright (C) 2001-2010 Free Software Foundation
 
    Authors: Philippe C.D. Robert
             Serg Stoyan
+	    Riccardo Mottola
 
    This file is part of GNUstep.
 
@@ -131,6 +132,7 @@
                   forKey:PCCreationDate];
   [projectDict setObject:NSFullUserName() forKey:PCProjectCreator];
   [projectDict setObject:NSFullUserName() forKey:PCProjectMaintainer];
+  [projectDict setObject:[NSUserDefaults userLanguages] forKey:PCUserLanguages];
 
   // Copy the project files to the provided path
 
@@ -207,14 +209,12 @@
       [resources addObjectsFromArray:[projectDict objectForKey:key]];
     }
   // Remove localized resource files from gathered array
-  count = [resources count];
   localizedResources = [projectDict objectForKey:PCLocalizedResources];
-  for (i = 0; i < count; i++)
+  for (i = [resources count] - 1; i >= 0; i--)
     {
       if ([localizedResources containsObject:[resources objectAtIndex:i]])
 	{
 	  [resources removeObjectAtIndex:i];
-	  count--;
 	}
     }
   [mf appendResources:resources inDir:@"Resources"];
@@ -247,7 +247,7 @@
 
 - (void)appendHead:(PCMakefileFactory *)mff
 {
-  NSString *installDir = [projectDict objectForKey:PCInstallDir];
+  NSString *installDomain = [projectDict objectForKey:PCInstallDomain];
 
   [mff appendString:@"\n#\n# Bundle\n#\n"];
   [mff appendString:[NSString stringWithFormat:@"VERSION = %@\n",
@@ -261,16 +261,14 @@
   [mff appendString:[NSString stringWithFormat:@"BUNDLE_EXTENSION = %@\n",
     [projectDict objectForKey:PCBundleExtension]]];
 
-  if ([installDir isEqualToString:@""])
+  /* FIXME %@_COPY_INTO_DIR needs to be properly reinstantiated
+     as well as %@_STANDARD_INSTALL = no  */
+
+  /* set the domain if it was specified */
+  if (!(installDomain == nil) && ![installDomain isEqualToString:@""])
     {
       [mff appendString:
-	[NSString stringWithFormat:@"%@_STANDARD_INSTALL = no\n",
-        projectName]];
-    }
-  else
-    {
-      [mff appendString:[NSString stringWithFormat:@"BUNDLE_INSTALL_DIR = %@\n",
-        installDir]];
+	     [NSString stringWithFormat:@"GNUSTEP_INSTALLATION_DOMAIN = %@\n", [installDomain uppercaseString]]];
     }
 }
 
