@@ -121,6 +121,7 @@
                   forKey:PCCreationDate];
   [projectDict setObject:NSFullUserName() forKey:PCProjectCreator];
   [projectDict setObject:NSFullUserName() forKey:PCProjectMaintainer];
+  [projectDict setObject:[NSUserDefaults userLanguages] forKey:PCUserLanguages];
 
   // Copy the project files to the provided path
 
@@ -239,14 +240,12 @@
       [resources addObjectsFromArray:[projectDict objectForKey:key]];
     }
   // Remove localized resource files from gathered array
-  count = [resources count];
   localizedResources = [projectDict objectForKey:PCLocalizedResources];
-  for (i = 0; i < count; i++)
+  for (i = [resources count] - 1; i >= 0; i--)
     {
       if ([localizedResources containsObject:[resources objectAtIndex:i]])
 	{
 	  [resources removeObjectAtIndex:i];
-	  count--;
 	}
     }
   [mf appendResources:resources inDir:@"Resources"];
